# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: blickfeld/core_processing/config/demo_recording.proto
# plugin: python-betterproto
from dataclasses import dataclass

import blickfeld_qb2.betterproto as betterproto
import blickfeld_qb2.betterproto.lib.google.protobuf as betterproto_lib_google_protobuf


class DemoRecording(betterproto.Enum):
    """
    Demo recording which can be replayed instead of the real sensor data. This
    is also used for virtual devices which have no physical sensing unit.
    WARNING: The recordings are still preliminary. The demo test data concept
    will be refactored soon.
    """

    DEMO_RECORDING_UNSPECIFIED = 0
    """No demo recoding is specified"""

    DEMO_RECORDING_HIGH_RESOLUTION = 1
    """High resolution recording in the office with 200 + 30 scanlines"""

    DEMO_RECORDING_HIGH_FRAME_RATE = 2
    """High resolution recording in the office with 30 + 30 scanlines"""
